<?php
//    LaNewsFactory - web news engine written in PHP
//    Copyright (C) 2000-2003 Christophe Brocas - christophe.brocas@free.fr
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA


// Returns the date/time stored in the news when you create/answer it.
//  That is the date/time displayed when the news is displayed.
//
function getdateaffichage()
{
  global $LNF_timedif;
  return strftime("%d/%m/%Y, %Hh%M:%S",mktime(date("H")+$LNF_timedif,date("i"),date("s"),date("m"),date("d"),date("Y")));
}

// These words are keywords into message files:
// $reservedwds = array("titre#", "email#", "nom#", "date#", "corps#", "EOAR#", "BOAN#", "rep#", "EOAN#");


// Returns the date portion of the filename in which the news is stored.
//
function getdatefichier()
{
  global $LNF_timedif;
  return strftime("%Y%m%d-%H%M%S",mktime(date("H")+$LNF_timedif,date("i"),date("s"),date("m"),date("d"),date("Y")));
}


// Returns user settings in a tab 
//
function GetUserSettings($filepath="usersettings.phpx")
{
  global $LNF_file_extension;
 
  // if the filepath is not supplied, set it with a filename
  //   which has the correct extension 
  if ($filepath == "usersettings.phpx")
     $filepath = "usersettings".$LNF_file_extension;

  $i=0;

  $f=fopen($filepath,"r");
  $ligne = fgets($f,16000);

  while (!feof($f))
  {
    $ligne = ereg_replace("\n","",$ligne);   
    $ligne = ereg_replace("\"","",$ligne);   
    $ligne = ereg_replace(";","",$ligne);   
    
    $tab[$i]=$ligne;
 
    $i++;
    $ligne = fgets($f,16000);
  }

  return $tab;  
}

// Checks if the string contains only letters or figures
//
function CheckString($dirname) 
{
  $length = strlen($dirname);
  $pattern = "^[0-9a-z]+$";
  return eregi($pattern, $dirname);
}


// Returns an array with all the files that exist in the directory pathname
//  and whose name include the pattern 
//
Function ListDirInArray($pattern, $pathname="news")
{
  $i=0;
  $directory = opendir($pathname);

  // No mask used, we return all files in the directory

  if ($pattern=="")
  {
     while ($filename = readdir($directory))
     {
           $tab[$i++]=$filename;
     }
  }
  else
  {
     while ($filename = readdir($directory))
     {
        if (ereg("$pattern$",$filename)==TRUE) 
           $tab[$i++]=$filename;
     }
  }

  return $tab;
}


// This funcions strip all reserved world from any text in input fields
//  (to avoid problems when parse news files)
//  Additionally add word "null" if the string is empty
//
function StripReservedWords ($str2chk) {
 
    // No more used for the moment.
    /* 
    // These words are keywords into message files:
    $reservedwds = array("titre#", "email#", "nom#", "date#", "corps#", "EOAR#", "BOAN#", "rep#", "EOAN#");

    while (list($key, $val) = each($reservedwds)) {
        $str2chk=ereg_replace("$val", " ", $str2chk);
    }
    */ 
    

    // If string len is 0 or has spaces only the "null" string is place
    // (do not avoid blank submit, but shows something instead of nothing)
    if (!strlen(trim($str2chk)))
        $str2chk = "null";
    return $str2chk;
}

// This function tests if the email adress is valid. The code comes from example furnished
// in example of ereg function in www.php.net online help.
//
function ValidEmailAdress($emailtotest) 
{
  return ereg("^[0-9a-z]([-_.]?[0-9a-z])*@[0-9a-z]([-.]?[0-9a-z])*\\.[a-wyz][a-z](g|l|m|pa|t|u|v)?$", $emailtotest);
}

// This function extracts the topic out of the file name
//
function GetTopic($filename) 
{
  $f1 = explode(".xml",$filename);
  $f2 = explode("-",$f1[0]);
  $i = sizeof($f2);
  return $f2[$i-1];
}

// This function gets the image associates to a particular topic
//
function GetTopicImage($topicname) 
{
  global $LNF_file_extension;
 
  include "news/$topicname-usersettings".$LNF_file_extension;
  return $LNF_image_topic;
}

// This function comes from the user contributed notes of the version_compare function
// documentation on php.net.
// It returns TRUE if the current version is equal or higher to the version
// passed on argument. FALSE otherwise.
//
function minimum_version( $vercheck ) 
{
    $minver = explode(".", $vercheck);
    $curver = explode(".", phpversion());
    if (($curver[0] < $minver[0])
      || (($curver[0] = $minver[0])
         && ($curver[1] < $minver[1]))
      || (($curver[0] = $minver[0]) && ($curver[1] = $minver[1])
         && ($curver[2][0] < $minver[2][0])))
        return false;
    else
        return true;
}     


 /********************************************************************\
 *               convert_tag($text, $tag, $option=0)
 **********************************************************************
 *
 * DESCRIPTION:  converts all occurences of a tag in text that has been 
 *               'htmlentities'ed or 'htmlspecialchars'ed back to its 
 *               original state.  this is useful if you JUST want <a> 
 *               tags to stay as html tags, or <b> tags, etc.
 *
 **********************************************************************
 *
 *    an example of calling this function for <a> tags would
 *    be:  $text = convert_tag($text, "a")
 *
 *    ie, don't include the < or >'s around the tag
 *
 **********************************************************************
 *
 *    another example, it will convert:
 *
 * &lt;b&gt;&lt;font size=&#039;1&#039;&gt;some text here&lt;/font&gt;&lt;/b&gt;
 *
 *    to:
 *
 * <b >&lt;font size='1'&gt;some text here&lt;/font&gt;</b>
 *
 *    if you call the function with: $text = convert_tag($text, "b");
 *
 **********************************************************************
 *
 *    another example, it will convert:
 *
 * &lt;b&gt;&lt;font size=&#039;1&#039;&gt;some text here&lt;/font&gt;&lt;/b&gt;
 *
 *    to:
 *
 * &lt;b&gt;<font size='1'>some text here</font>&lt;/b&gt;
 *
 *    if you call the function with: $text = convert_tag($text, "font", 3);
 *
 **********************************************************************
 * VARIABLES:
 *
 * (1) text :: string :: the text to convert tags in
 *
 * (2) tag :: string :: this is the tag to convert.  don't include the
 *                      < or >'s.  ie, for <b> just do "b" as $tag
 *
 * (3) option :: int :: these values effect the functionality of this
 *                      function.
 *            :: 1 :: this will make the function convert any
 *                    single quotes within the tag as well.
 *            :: 2 :: this will make the function convert any
 *                    double quotes within the tag as well.
 *            :: 3 :: this will make the function convert any
 *                    single or double quotes within the tag as well.
 *
 **********************************************************************
 *
 * RETURN:
 *
 * the converted $text
 *
 \********************************************************************/
function convert_tag($text, $tag, $option=0)
{
    if($option == 1 || $option == 3)
    $single = 1;
    if($option == 2 || $option == 3)
    $double = 1;

    // convert the start tags (ie, <b>)
    $text = preg_replace("'&lt;[[:space:]]*$tag([[:space:]]+(.*?)&gt;|&gt;)'i", "<$tag \\2>", $text);
    // convert the end tags (ie, </b>)
    $text = eregi_replace("&lt;[[:space:]]*/$tag([[:space:]])*&gt;", "</$tag>", $text);

    // we have to go through and convert all of the single quotes within the given tag
    // we can't just use one regex because we don't know how many quotes there will be
    if($single)
    {
    while($text != $temp_text)
    {
        if($temp_text)
        $text = $temp_text;

        $temp_text = preg_replace("'(<$tag .*?)&#039;(.*?)>'i", "\\1'\\2>", $text);
    }

    $temp_text="";
    }

    // we have to go through and convert all of the double quotes within the given tag
    // we can't just use one regex because we don't know how many quotes there will be
    if($double)
    {
    while($text != $temp_text)
    {
        if($temp_text)
        $text = $temp_text;

        $temp_text = preg_replace("'(<$tag .*?)&quot;(.*?)>'i", "\\1\"\\2>", $text);
    }

    $temp_text="";
    }

    return $text;
}

// Initial HTML strings are restored by this function
// after a conversion due to the PHP htmlspecialchars function 
function reverse_htmlspecialchars($text)
{
	$text=ereg_replace('&gt;', '>', $text);
	$text=ereg_replace('&lt;', '<', $text);
	$text=ereg_replace('&quot;', "\"", $text);
	$text=ereg_replace('&amp;', '&', $text);

	return $text;
}

// This function returns the function argument cleaned.
// Cleaning means here :
// . deleting <script> and </script> tags from the string
function cleaning_input($input_string)
{
	$input_string = ereg_replace('<'.'script'.'>', '', $input_string);
	$input_string = ereg_replace('</'.'script'.'>', '', $input_string);

	return 	$input_string;
}


// This function returns FALSE if the function argument is empty or full of blanks.
function Valid_Input($input_string)
{
  if (strlen(rtrim(ltrim($input_string))) == 0)
     return FALSE;
  else
     return TRUE;
}
?>